summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSergey Kosukhin <sergey.kosukhin@mpimet.mpg.de>2022-04-11 23:34:09 +0200
committerGitHub <noreply@github.com>2022-04-11 14:34:09 -0700
commit6e5cba7b8269370bdcef072a67bf540de53799ac (patch)
treed9d2cf6f7400d4041d8c72cba8105aed377eab07
parentb45e734b59c2d5573cd2572b0dab6d9ab47275f3 (diff)
downloadspack-6e5cba7b8269370bdcef072a67bf540de53799ac.tar.gz
spack-6e5cba7b8269370bdcef072a67bf540de53799ac.tar.bz2
spack-6e5cba7b8269370bdcef072a67bf540de53799ac.tar.xz
spack-6e5cba7b8269370bdcef072a67bf540de53799ac.zip
cray platform: unload cray-mpich (#29898)
-rw-r--r--lib/spack/spack/build_environment.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/spack/spack/build_environment.py b/lib/spack/spack/build_environment.py
index 5f9e1d8100..d967b69911 100644
--- a/lib/spack/spack/build_environment.py
+++ b/lib/spack/spack/build_environment.py
@@ -825,12 +825,13 @@ def setup_package(pkg, dirty, context='build'):
for mod in pkg.compiler.modules:
load_module(mod)
# kludge to handle cray libsci being automatically loaded by PrgEnv
# modules on cray platform. Module unload does no damage when
# unnecessary
on_cray, _ = _on_cray()
if on_cray:
- module('unload', 'cray-libsci')
+ for mod in ['cray-mpich', 'cray-libsci']:
+ module('unload', mod)
if target.module_name:
load_module(target.module_name)
@@ -825,12 +825,13 @@ def setup_package(pkg, dirty, context='build'):
for mod in pkg.compiler.modules:
load_module(mod)
- # kludge to handle cray libsci being automatically loaded by PrgEnv
- # modules on cray platform. Module unload does no damage when
+ # kludge to handle cray mpich and libsci being automatically loaded by
+ # PrgEnv modules on cray platform. Module unload does no damage when
# unnecessary
on_cray, _ = _on_cray()